diff --git a/ChangeLog b/ChangeLog
index 6b9f8d5d..652ce12a 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -21,7 +21,6 @@
TODO fix .tar.gz Linux release 3.5.3 on Sourceforge (gives compile errors)
-TODO fix whats this help for server list selection combo box (in client and server)
diff --git a/src/clientsettingsdlg.cpp b/src/clientsettingsdlg.cpp
index eb938a21..bfdc3cc0 100755
--- a/src/clientsettingsdlg.cpp
+++ b/src/clientsettingsdlg.cpp
@@ -242,7 +242,7 @@ CClientSettingsDlg::CClientSettingsDlg ( CClient* pNCliP, QWidget* parent,
edtNewClientLevel->setWhatsThis ( strNewClientLevel );
edtNewClientLevel->setAccessibleName ( tr ( "New client level edit box" ) );
- // central server address
+ // custom central server address
QString strCentrServAddr = "" + tr ( "Custom Central Server Address" ) + ": " +
tr ( "The custom central server address is the IP address or URL of the central "
"server at which the server list of the connection dialog is managed. This "
diff --git a/src/connectdlg.cpp b/src/connectdlg.cpp
index 825fa5c4..96e5288d 100755
--- a/src/connectdlg.cpp
+++ b/src/connectdlg.cpp
@@ -84,6 +84,10 @@ CConnectDlg::CConnectDlg ( CClient* pNCliP,
cbxCentServAddrType->addItem ( csCentServAddrTypeToString ( AT_GENRE_JAZZ ) );
cbxCentServAddrType->addItem ( csCentServAddrTypeToString ( AT_CUSTOM ) );
+ cbxCentServAddrType->setWhatsThis ( "" + tr ( "Server List Selection" ) + ": " + tr (
+ "Selects the server list to be shown." ) );
+ cbxCentServAddrType->setAccessibleName ( tr ( "Server list selection combo box" ) );
+
// filter
edtFilter->setWhatsThis ( "" + tr ( "Filter" ) + ": " + tr ( "The server "
"list is filtered by the given text. Note that the filter is case insensitive." ) );
diff --git a/src/serverdlg.cpp b/src/serverdlg.cpp
index 9a369acb..87a1131d 100755
--- a/src/serverdlg.cpp
+++ b/src/serverdlg.cpp
@@ -73,22 +73,22 @@ CServerDlg::CServerDlg ( CServer* pNServP,
// register server status label
lblRegSvrStatus->setWhatsThis ( "" + tr ( "Register Server Status" ) + ": " +
tr ( "If the Make My Server Public check box is checked, this will show "
- "whether registration with the central server is successful." ) );
+ "whether registration with the central server is successful. If the "
+ "registration failed, please choose another server list." ) );
- // central server address
- QString strCentrServAddr = "" + tr ( "Central Server Address" ) + ": " +
- tr ( "The Central server address is the IP address or URL of the central server "
- "at which this server is registered. With the central server address "
- "type either the local region can be selected of the default central "
- "servers or a manual address can be specified." );
+ // custom central server address
+ QString strCentrServAddr = "" + tr ( "Custom Central Server Address" ) + ": " +
+ tr ( "The custom central server address is the IP address or URL of the central "
+ "server at which the server list of the connection dialog is managed." );
lblCentralServerAddress->setWhatsThis ( strCentrServAddr );
- cbxCentServAddrType->setWhatsThis ( strCentrServAddr );
edtCentralServerAddress->setWhatsThis ( strCentrServAddr );
-
- cbxCentServAddrType->setAccessibleName ( tr ( "Default central server type combo box" ) );
edtCentralServerAddress->setAccessibleName ( tr ( "Central server address line edit" ) );
+ cbxCentServAddrType->setWhatsThis ( "" + tr ( "Server List Selection" ) + ": " + tr (
+ "Selects the server list (i.e. central server address) in which your server will be added." ) );
+ cbxCentServAddrType->setAccessibleName ( tr ( "Server list selection combo box" ) );
+
// server name
QString strServName = "" + tr ( "Server Name" ) + ": " + tr ( "The server name identifies "
"your server in the connect dialog server list at the clients. If no "